@@ -20,6 +20,8 @@ sub new {
 sub build_requires {
     return +{
 	'Test::More'	=> 0.88,	# Because of done_testing().
+	charnames	=> 0,
+	lib		=> 0,
     };
 }
 
@@ -39,7 +41,7 @@ sub meta_merge {
 	},
 	resources	=> {
 	    bugtracker	=> {
-                web	=> 'https://rt.cpan.org/Public/Dist/Display.html?Name=PPIx-Regexp',
+                web	=> 'https://github.com/trwyant/perl-PPIx-Regexp/issues',
                 mailto  => 'wyant@cpan.org',
             },
 	    license	=> 'http://dev.perl.org/licenses/',
@@ -70,12 +72,14 @@ sub requires {
 ##  }
     return {
         'Carp'			=> 0,
+	'Encode'		=> 0,
         'Exporter'		=> 0,
-        'List::MoreUtils'	=> 0,
         'List::Util'		=> 0,
 	'PPI::Document'		=> 1.117,	# for new( readonly => 1 )
+	'PPI::Dumper'		=> 1.117,
         'Scalar::Util'		=> 0,
 	'Task::Weaken'		=> 0,
+	'Text::Tabs'		=> 0,
 	'base'			=> 0,
         'constant'		=> 0,
         'strict'		=> 0,
@@ -88,7 +92,6 @@ sub requires_perl {
     return 5.006;
 }
 
-
 1;
 
 __END__
@@ -187,7 +190,6 @@ This method returns the version of Perl required by the package.
 
 This class has no public attributes.
 
-
 =head1 ENVIRONMENT
 
 =head2 MAKING_MODULE_DISTRIBUTION
@@ -196,11 +198,11 @@ This environment variable should be set to a true value if you are
 making a distribution. This ensures that no configuration-specific
 information makes it into F<META.yml>.
 
-
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<https://rt.cpan.org>, or in electronic mail to the author.
+L<https://github.com/trwyant/perl-PPIx-Regexp/issues>, or in electronic
+mail to the author.
 
 =head1 AUTHOR
 
@@ -208,7 +210,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2010-2020 by Thomas R. Wyant, III
+Copyright (C) 2010-2021 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
