@@ -15,7 +15,7 @@ use PPIx::Regexp::Util qw{ __choose_tokenizer_class __instance };
 use Scalar::Util qw{ looks_like_number refaddr };
 use Test::More 0.88;
 
-our $VERSION = '0.069';
+our $VERSION = '0.078';
 
 use constant ARRAY_REF	=> ref [];
 
@@ -35,8 +35,10 @@ our @EXPORT_OK = qw{
     false
     finis
     equals
+    is
     navigate
     note
+    ok
     parse
     pass
     plan
@@ -231,7 +233,7 @@ sub finis {
 
 {
 
-    my %array = map { $_ => 1} qw{
+    my %array = map { $_ => 1 } qw{
 	children delimiters finish schildren start tokens type
     };
 
@@ -720,7 +722,8 @@ subroutine.
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<https://rt.cpan.org>, or in electronic mail to the author.
+L<https://github.com/trwyant/perl-PPIx-Regexp/issues>, or in electronic
+mail to the author.
 
 =head1 AUTHOR
 
@@ -728,7 +731,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2020 by Thomas R. Wyant, III
+Copyright (C) 2009-2021 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
