@@ -41,7 +41,7 @@ use base qw{ PPIx::Regexp::Token };
 
 use PPIx::Regexp::Constant qw{ @CARP_NOT };
 
-our $VERSION = '0.069';
+our $VERSION = '0.078';
 
 # Return true if the token can be quantified, and false otherwise
 # sub can_be_quantified { return };
@@ -60,6 +60,15 @@ our $VERSION = '0.069';
 ##    return;
 ##}
 
+=head2 is_matcher
+
+This method returns a true value because a character class actually
+matches something.
+
+=cut
+
+sub is_matcher { return 1; }
+
 1;
 
 __END__
@@ -67,7 +76,8 @@ __END__
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<https://rt.cpan.org>, or in electronic mail to the author.
+L<https://github.com/trwyant/perl-PPIx-Regexp/issues>, or in electronic
+mail to the author.
 
 =head1 AUTHOR
 
@@ -75,7 +85,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2020 by Thomas R. Wyant, III
+Copyright (C) 2009-2021 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
