@@ -46,7 +46,7 @@ use PPIx::Regexp::Constant qw{
     @CARP_NOT
 };
 
-our $VERSION = '0.069';
+our $VERSION = '0.078';
 
 use constant UNICODE_PROPERTY_LITERAL_VALUE => qr/
 		\{ \s* \^? \w [\w:=\s-]* \} |
@@ -59,12 +59,18 @@ use constant UNICODE_PROPERTY_LITERAL =>
 
 # CAVEAT: The following regular expression, despite its name, matches
 # ALL unicode property values. To actually match a wildcard property you
-# must first eliminate anything that matches UNICODE_PROPERTY_LITERAL.
+# must first eliminate anything that matches UNICODE_PROPERTY_LITERAL or
+# UNICODE_PROPERTY_NAME_MATCH
 use constant UNICODE_PROPERTY_WILDCARD =>
     qr/ \A \\ [Pp] \{ \s* [\w\s-]+ [:=] [^}]+ \} /smx;
 
+use constant UNICODE_PROPERTY_NAME_MATCH =>
+    qr< \A \\ [Pp] \{ \s* na (?: me? )? [:=] / [^/]+ / \} >smx;
+
 use constant UNICODE_PROPERTY =>
-    qr/ @{[ UNICODE_PROPERTY_LITERAL ]} | @{[ UNICODE_PROPERTY_WILDCARD ]} /smx;
+    qr/ @{[ UNICODE_PROPERTY_LITERAL ]} |
+	@{[ UNICODE_PROPERTY_NAME_MATCH ]} |
+	@{[ UNICODE_PROPERTY_WILDCARD ]} /smx;
 
 {
 
@@ -203,6 +209,8 @@ use constant UNICODE_PROPERTY =>
 #	    and return '5.011003';
 	$content  =~ UNICODE_PROPERTY_LITERAL
 	    and return '5.006001';
+	$content =~ UNICODE_PROPERTY_NAME_MATCH
+	    and return '5.031010';
 	$content =~ UNICODE_PROPERTY_WILDCARD
 	    and return '5.029009';
 	return MINIMUM_PERL;
@@ -291,7 +299,8 @@ __END__
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<https://rt.cpan.org>, or in electronic mail to the author.
+L<https://github.com/trwyant/perl-PPIx-Regexp/issues>, or in electronic
+mail to the author.
 
 =head1 AUTHOR
 
@@ -299,7 +308,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2020 by Thomas R. Wyant, III
+Copyright (C) 2009-2021 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
