@@ -39,11 +39,25 @@ use PPIx::Regexp::Constant qw{
     LITERAL_LEFT_CURLY_ALLOWED
     LITERAL_LEFT_CURLY_REMOVED_PHASE_1
     LITERAL_LEFT_CURLY_REMOVED_PHASE_2
+    LITERAL_LEFT_CURLY_REMOVED_PHASE_3
     MINIMUM_PERL MSG_PROHIBITED_BY_STRICT
     TOKEN_UNKNOWN
+    @CARP_NOT
 };
 
-our $VERSION = '0.055';
+our $VERSION = '0.078';
+
+sub __new {
+    my ( $class, $content, %arg ) = @_;
+
+    my $self = $class->SUPER::__new( $content, %arg )
+	or return;
+
+    defined $arg{ordinal}
+	and $self->{ordinal} = $arg{ordinal};
+
+    return $self;
+}
 
 # Return true if the token can be quantified, and false otherwise
 # sub can_be_quantified { return };
@@ -52,11 +66,25 @@ sub explain {
     return 'Literal character';
 }
 
+=head2 is_matcher
+
+This method returns a true value because a literal matches itself.
+
+=cut
+
+sub is_matcher { return 1; }
+
 sub perl_version_introduced {
     my ( $self ) = @_;
     exists $self->{perl_version_introduced}
 	and return $self->{perl_version_introduced};
-    ( my $content = $self->content() ) =~ m/ \A \\ o /smx
+    my $content = $self->content();
+    my $main = $self->main_structure();
+    $main
+	and $content =~ m/ \A \\ N \{ /smx
+	and not $main->interpolates()
+	and return ( $self->{perl_version_introduced} = '5.029010' );
+    $content =~ m/ \A \\ o /smx
 	and return ( $self->{perl_version_introduced} = '5.013003' );
     $content =~ m/ \A \\ N [{] U [+] /smx
 	and return ( $self->{perl_version_introduced} = '5.008' );
@@ -71,11 +99,31 @@ sub perl_version_introduced {
     my %removed = (
 	q<{>	=> sub {
 	    my ( $self ) = @_;
-	    # Un-escaped literal left curlys are always allowed when
-	    # they begin the regexp or the group.
-	    my $prev = $self->sprevious_sibling()
-		or return LITERAL_LEFT_CURLY_ALLOWED;
-	    return $prev->__following_literal_left_curly_disallowed_in();
+
+	    my $prev;
+
+	    if ( $prev = $self->sprevious_sibling() ) {
+		# When an unescaped left curly follows something else in
+		# the same structure, the logic on whether it is allowed
+		# lives, for better or worse, on the sibling.
+		return $prev->__following_literal_left_curly_disallowed_in();
+	    } elsif ( $prev = $self->sprevious_element() ) {
+		# Perl 5.27.8 deprecated unescaped literal left curlys
+		# after a left paren that introduces a group. Therefore
+		# the left curly has no previous sibling. But the curly
+		# is still legal at the beginning of a regex, even one
+		# delimited by parens, so we can not return when we find
+		# a PPIx::Regexp::Token::Delimiter, which is a subclass
+		# of PPIx::Regexp::Token::Structure.
+		$prev->isa( 'PPIx::Regexp::Token::Structure' )
+		    and q<(> eq $prev->content()
+		    and not $prev->isa( 'PPIx::Regexp::Token::Delimiter' )
+		    and return LITERAL_LEFT_CURLY_REMOVED_PHASE_3;
+	    }
+	    # When this mess started, the idea was to always allow
+	    # unescaped literal left curlies that started a regex or a
+	    # group
+	    return LITERAL_LEFT_CURLY_ALLOWED;
 	},
     );
 
@@ -242,7 +290,6 @@ sub __PPIX_TOKENIZER__regexp {
     return;
 }
 
-
 =begin comment
 
 The following is from perlop:
@@ -269,6 +316,9 @@ The following is from perlop:
     my %special = (
 	'\\N{}'	=> sub {
 	    my ( $tokenizer, $accept ) = @_;
+
+=begin comment
+
 	    $tokenizer->strict()
 		or return $tokenizer->make_token( $accept,
 		'PPIx::Regexp::Token::NoOp', {
@@ -284,6 +334,36 @@ The following is from perlop:
 		},
 	    );
 
+=end comment
+
+=cut
+
+	    return $tokenizer->make_token( $accept, TOKEN_UNKNOWN, {
+		    error	=> 'Empty Unicode character name',
+		    perl_version_introduced	=> '5.023008',
+		    perl_version_removed	=> '5.027001',
+		},
+	    );
+	},
+
+	'\\o{}' => sub {
+	    my ( $tokenizer, $accept ) = @_;
+	    return $tokenizer->make_token( $accept, TOKEN_UNKNOWN, {
+		    error	=> q<Empty \\o{} is an error>,
+		},
+	    );
+	},
+
+	'\\x{}' => sub {
+	    my ( $tokenizer, $accept ) = @_;
+	    $tokenizer->strict()
+		and return $tokenizer->make_token( $accept,
+		TOKEN_UNKNOWN, {
+		    error	=>
+			q<Empty \\x{} is an error under "use re 'strict'">,
+		},
+	    );
+	    return $accept;
 	},
     );
 
@@ -293,6 +373,42 @@ The following is from perlop:
 	$character eq '\\'
 	    or return;
 
+	if ( my $accept = $tokenizer->find_regexp(	# {
+		qr< \A \\ ( [ox] ) [{] ( [^}]* ) [}] >smx
+	    ) ) {
+	    my $match = $tokenizer->match();
+	    my $code;
+	    $code = $special{$match}
+		and return $code->( $tokenizer, $accept );
+	    my ( $kind, $value ) = $tokenizer->capture();
+	    my $invalid = {
+		o	=> qr<[^0-7]>smx,
+		x	=> qr<[[:^xdigit:]]>smx,
+	    }->{$kind};
+	    $value =~ m/ $invalid /smxg		# /g for pos()
+		or return $accept;
+	    $tokenizer->strict()
+		and return $tokenizer->make_token( $accept,
+		TOKEN_UNKNOWN, {
+		    error	=> sprintf(
+			'Non-%s character in \\%s{...}',
+			{
+			    o	=> 'octal',
+			    x	=> 'hex',
+			}->{$kind},
+			$kind,
+		    ),
+		},
+	    );
+	    return $tokenizer->make_token( $accept, __PACKAGE__, {
+		    ordinal	=> {
+			o	=> sub { oct $_[0] },
+			x	=> sub { hex $_[0] },
+		    }->{$kind}->( substr( $value, 0, pos $value ) || 0 ),
+		},
+	    );
+	}
+
 	if ( my $accept = $tokenizer->find_regexp(
 		qr< \A \\ (?:
 		    [^\w\s] |		# delimiters/metas
@@ -300,11 +416,12 @@ The following is from perlop:
 		    0 [01234567]{0,2} |	# octal
 #		    [01234567]{1,3} |	# made from backref by lexer
 		    c [][\@[:alpha:]\\^_?] |	# control characters
-		    x (?: \{ [[:xdigit:]]* \} | [[:xdigit:]]{0,2} ) | # hex
-		    o [{] [01234567]+ [}] |	# octal as of 5.13.3
+##		    x (?: \{ [[:xdigit:]]* \} | [[:xdigit:]]{0,2} ) | # hex
+##		    o [{] [01234567]+ [}] |	# octal as of 5.13.3
+		    x [[:xdigit:]]{0,2} | # hex - brackets handled above
 ##		    N (?: \{ (?: [[:alpha:]] [\w\s:()-]* | # must begin w/ alpha
 ##		    U [+] [[:xdigit:]]+ ) \} ) |	# unicode
-		    N (?: [{] (?= \D ) [^\}]* [}] )	# unicode
+		    N (?: [{] (?= [^0-9] ) [^\}]* [}] )	# unicode
 		) >smx ) ) {
 	    my $match = $tokenizer->match();
 	    my $code;
@@ -312,6 +429,7 @@ The following is from perlop:
 		and return $code->( $tokenizer, $accept );
 	    return $accept;
 	}
+
 	return;
     }
 }
@@ -326,8 +444,9 @@ It is analogous to the C<ord> built-in.
 
 It will not attempt to determine the ordinal of a unicode name
 (C<\N{...}>) unless L<charnames|charnames> has been loaded, and supports
-the L<vianame()|charnames/vianame> function. Instead, it will return
-C<undef>. Users of Perl 5.6.2 and older may be out of luck here.
+the L<vianame()|charnames/charnames::vianame(I<name>)> function.
+Instead, it will return C<undef>. Users of Perl 5.6.2 and older may be
+out of luck here.
 
 Unicode code points (e.g. C<\N{U+abcd}>) should work independently of
 L<charnames|charnames>, and just return the value of C<abcd>.
@@ -429,16 +548,16 @@ because I don't understand the syntax.
 	$octal{$indicator} and return oct substr $content, 1;
 
 	if ( $indicator eq 'x' ) {
-	    $content =~ m/ \A \\ x \{ ( [[:xdigit:]]+ ) \} \z /smx
-		and return hex $1;
+	    $content =~ m/ \A \\ x \{ ( [[:xdigit:]]* ) /smx
+		and return hex "0$1";
 	    $content =~ m/ \A \\ x ( [[:xdigit:]]{0,2} ) \z /smx
 		and return hex $1;
 	    return;
 	}
 
 	if ( $indicator eq 'o' ) {
-	    $content =~ m/ \A \\ o [{] ( [01234567]+ ) [}] \z /smx
-		and return oct $1;
+	    $content =~ m/ \A \\ o [{] ( [01234567]* ) \z /smx
+		and return oct "0$1";
 	    return;	# Shouldn't happen, but ...
 	}
 
@@ -511,7 +630,8 @@ __END__
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<http://rt.cpan.org>, or in electronic mail to the author.
+L<https://github.com/trwyant/perl-PPIx-Regexp/issues>, or in electronic
+mail to the author.
 
 =head1 AUTHOR
 
@@ -519,7 +639,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2018 by Thomas R. Wyant, III
+Copyright (C) 2009-2021 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
